@@ -36,15 +36,15 @@ pub fn expand_tabs(line: &str, width: usize, cursor: &mut usize) -> String {
 fn try_parse_utf8_char(input: &[u8]) -> Option<(char, usize)> {
     let str_from_utf8 = |seq| std::str::from_utf8(seq).ok();
 
-    let decoded = None
-        .or(input.get(0..1).and_then(str_from_utf8).map(|c| (c, 1)))
-        .or(input.get(0..2).and_then(str_from_utf8).map(|c| (c, 2)))
-        .or(input.get(0..3).and_then(str_from_utf8).map(|c| (c, 3)))
-        .or(input.get(0..4).and_then(str_from_utf8).map(|c| (c, 4)));
+    let decoded = input
+        .get(0..1)
+        .and_then(str_from_utf8)
+        .map(|c| (c, 1))
+        .or_else(|| input.get(0..2).and_then(str_from_utf8).map(|c| (c, 2)))
+        .or_else(|| input.get(0..3).and_then(str_from_utf8).map(|c| (c, 3)))
+        .or_else(|| input.get(0..4).and_then(str_from_utf8).map(|c| (c, 4)));
 
-    let decoded_char = decoded.map(|(seq, n)| (seq.chars().next().unwrap(), n));
-
-    decoded_char
+    decoded.map(|(seq, n)| (seq.chars().next().unwrap(), n))
 }
 
 pub fn replace_nonprintable(input: &[u8], tab_width: usize) -> String {
@@ -60,7 +60,7 @@ pub fn replace_nonprintable(input: &[u8], tab_width: usize) -> String {
 
             match chr {
                 // space
-                ' ' => output.push('•'),
+                ' ' => output.push('·'),
                 // tab
                 '\t' => {
                     if tab_width == 1 {
@@ -72,7 +72,7 @@ pub fn replace_nonprintable(input: &[u8], tab_width: usize) -> String {
                     }
                 }
                 // line feed
-                '\x0A' => output.push('␊'),
+                '\x0A' => output.push_str("␊\x0A"),
                 // carriage return
                 '\x0D' => output.push('␍'),
                 // null
